.. image:: https://img.shields.io/pypi/v/yafowil.widget.image.svg
    :target: https://pypi.python.org/pypi/yafowil.widget.image
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/yafowil.widget.image.svg
    :target: https://pypi.python.org/pypi/yafowil.widget.image
    :alt: Number of PyPI downloads

.. image:: https://github.com/conestack/yafowil.widget.image/actions/workflows/test_py.yaml/badge.svg
    :target: https://github.com/conestack/yafowil.widget.image/actions/workflows/test_py.yaml
    :alt: Test yafowil.widget.image Python

.. image:: https://github.com/conestack/yafowil.widget.image/actions/workflows/test_js.yaml/badge.svg
    :target: https://github.com/conestack/yafowil.widget.image/actions/workflows/test_js.yaml
    :alt: Test yafowil.widget.image JS

This is an **image widget** for for `YAFOWIL
<http://pypi.python.org/pypi/yafowil>`_.

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#image>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.image/index.html>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/conestack/yafowil.widget.image>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Robert Niederreiter

- Georg Bernhard

- Lena Daxenbichler
